<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="73"/>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>MX Cleanup</source>
        <translation>Limpeza Automática do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>Clean Flatpak</source>
        <translation>Limpeza de Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Remove unused runtimes</source>
        <translation>Remover o runtimes que não estiver sendo utilizado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="718"/>
        <source>Clean Folders</source>
        <translation>Limpar Pastas </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Not accessed for:</source>
        <translation>Não foi acessado para:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="805"/>
        <source>All (potentially dangerous)</source>
        <translation>Todos (potencialmente perigosos)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="140"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <source>Empty Trash</source>
        <translation>Esvaziar a Lixeira</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Trash older than:</source>
        <translation>A lixeira está com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.ui" line="372"/>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Don&apos;t empty</source>
        <translation>Não esvaziar a lixeira</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="622"/>
        <location filename="../mainwindow.ui" line="724"/>
        <location filename="../mainwindow.cpp" line="335"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <location filename="../mainwindow.cpp" line="342"/>
        <source> days</source>
        <translation>dias</translation>
    </message>
    <message>
        <source>Not accessed for</source>
        <translation type="vanished">Não foi acessado por</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>All users</source>
        <translation>Todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Selected user</source>
        <translation>Usuário selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Clear APT Cache</source>
        <translation>Limpar a memória cache do APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Old files</source>
        <translation>Arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Ferramenta Gráfica para Analisar o Uso do Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Executar o Analisador de Uso do Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Schedule</source>
        <translation>Agendar a limpeza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>No automatic clean</source>
        <translation>Não fazer a limpeza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>At reboot</source>
        <translation>Na reinicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Free Disk Space for User</source>
        <translation>Espaço Livre em Disco para o Usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Select user to repair</source>
        <translation>Selecione o usuário para ser reparado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Select user:</source>
        <translation>Selecione o usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Delete Logs</source>
        <translation>Eliminar os Registros (Logs)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>All logs</source>
        <translation>Todos os registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Old logs</source>
        <translation>Registros antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Logs older than:</source>
        <translation>Os registros estão com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Kernel removal tool</source>
        <translation>Ferramenta de remoção de núcleo (kernel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>List and select kernels to remove</source>
        <translation>Listar e selecionar os núcleos (kernels) para serem removidos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <location filename="../mainwindow.cpp" line="343"/>
        <source> day</source>
        <translation>dia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>Cleanup command done</source>
        <translation>O comando de limpeza foi concluído com sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB foram liberados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Quick and safe removal of old files</source>
        <translation>Remoção rápida e segura de arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licença</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Relatório de alterações</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>O núcleo (kernel) atualmente em uso é &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Remove selected</source>
        <translation>Remover os itens selecionados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Os núcleos (kernels) similares que podem ser removidos:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>Other kernels that can be removed:</source>
        <translation>Outros núcleos (kernels) que podem ser removidos:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Não pode ser removido.&lt;/b&gt; Não é possível remover o núcleo (kernel) que está em uso.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Quick safe removal of old files</source>
        <translation>Remoção rápida e segura de arquivos antigos</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando a sessão com o usuário root. Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Relatório de Alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>
